# What is this?
- this is just a simple project I have created in python that helps you figure out how much money you should allocate to different kinds of expenses in your life.
- this was mainly created for programming practise and for personal use
- feel free to add any suggestions!
# How do I use it?
- you can download the program with pip - [pypi project site](https://pypi.org/project/eduwallet/)
```
pip install eduwallet
```
- after installation, run the program with
```
python3 -m eduwallet
```
# Latest Update v1.1.1
## v1.1.0 brings a bunch of added features!
- you can now save and manage your plans and the different categories within them, allowing you to track how much money you have spent
- added a lot of visual improvements
- improved user's ability to cancel an action
- removed some bugs
- and other small changes
## v1.1.1
- fixed some bugs
## v1.1.2
- added project on pypi for easier installation
# v1.1.3
- fixed plan saving issue
